@@ -24,7 +24,7 @@
  */
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
-#endif /* HAVE_CONFIG_H */
+#endif /* defined(HAVE_CONFIG_H) */
 
 #include <assert.h>
 #include <string.h>
@@ -39,6 +39,7 @@
 #include <openssl/chacha.h>
 #include <openssl/rand.h>
 
+#include "ngtcp2_macro.h"
 #include "shared.h"
 
 typedef enum ngtcp2_crypto_boringssl_cipher_type {
@@ -52,15 +53,15 @@ typedef struct ngtcp2_crypto_boringssl_cipher {
 } ngtcp2_crypto_boringssl_cipher;
 
 static ngtcp2_crypto_boringssl_cipher crypto_cipher_aes_128 = {
-    NGTCP2_CRYPTO_BORINGSSL_CIPHER_TYPE_AES_128,
+  NGTCP2_CRYPTO_BORINGSSL_CIPHER_TYPE_AES_128,
 };
 
 static ngtcp2_crypto_boringssl_cipher crypto_cipher_aes_256 = {
-    NGTCP2_CRYPTO_BORINGSSL_CIPHER_TYPE_AES_256,
+  NGTCP2_CRYPTO_BORINGSSL_CIPHER_TYPE_AES_256,
 };
 
 static ngtcp2_crypto_boringssl_cipher crypto_cipher_chacha20 = {
-    NGTCP2_CRYPTO_BORINGSSL_CIPHER_TYPE_CHACHA20,
+  NGTCP2_CRYPTO_BORINGSSL_CIPHER_TYPE_CHACHA20,
 };
 
 ngtcp2_crypto_aead *ngtcp2_crypto_aead_aes_128_gcm(ngtcp2_crypto_aead *aead) {
@@ -92,8 +93,8 @@ ngtcp2_crypto_aead *ngtcp2_crypto_aead_retry(ngtcp2_crypto_aead *aead) {
   return ngtcp2_crypto_aead_init(aead, (void *)EVP_aead_aes_128_gcm());
 }
 
-static const EVP_AEAD *crypto_ssl_get_aead(SSL *ssl) {
-  switch (SSL_CIPHER_get_id(SSL_get_current_cipher(ssl))) {
+static const EVP_AEAD *crypto_cipher_id_get_aead(uint32_t cipher_id) {
+  switch (cipher_id) {
   case TLS1_CK_AES_128_GCM_SHA256:
     return EVP_aead_aes_128_gcm();
   case TLS1_CK_AES_256_GCM_SHA384:
@@ -105,8 +106,8 @@ static const EVP_AEAD *crypto_ssl_get_aead(SSL *ssl) {
   }
 }
 
-static uint64_t crypto_ssl_get_aead_max_encryption(SSL *ssl) {
-  switch (SSL_CIPHER_get_id(SSL_get_current_cipher(ssl))) {
+static uint64_t crypto_cipher_id_get_aead_max_encryption(uint32_t cipher_id) {
+  switch (cipher_id) {
   case TLS1_CK_AES_128_GCM_SHA256:
   case TLS1_CK_AES_256_GCM_SHA384:
     return NGTCP2_CRYPTO_MAX_ENCRYPTION_AES_GCM;
@@ -117,8 +118,9 @@ static uint64_t crypto_ssl_get_aead_max_encryption(SSL *ssl) {
   }
 }
 
-static uint64_t crypto_ssl_get_aead_max_decryption_failure(SSL *ssl) {
-  switch (SSL_CIPHER_get_id(SSL_get_current_cipher(ssl))) {
+static uint64_t
+crypto_cipher_id_get_aead_max_decryption_failure(uint32_t cipher_id) {
+  switch (cipher_id) {
   case TLS1_CK_AES_128_GCM_SHA256:
   case TLS1_CK_AES_256_GCM_SHA384:
     return NGTCP2_CRYPTO_MAX_DECRYPTION_FAILURE_AES_GCM;
@@ -129,8 +131,9 @@ static uint64_t crypto_ssl_get_aead_max_decryption_failure(SSL *ssl) {
   }
 }
 
-static const ngtcp2_crypto_boringssl_cipher *crypto_ssl_get_hp(SSL *ssl) {
-  switch (SSL_CIPHER_get_id(SSL_get_current_cipher(ssl))) {
+static const ngtcp2_crypto_boringssl_cipher *
+crypto_cipher_id_get_hp(uint32_t cipher_id) {
+  switch (cipher_id) {
   case TLS1_CK_AES_128_GCM_SHA256:
     return &crypto_cipher_aes_128;
   case TLS1_CK_AES_256_GCM_SHA384:
@@ -142,8 +145,8 @@ static const ngtcp2_crypto_boringssl_cipher *crypto_ssl_get_hp(SSL *ssl) {
   }
 }
 
-static const EVP_MD *crypto_ssl_get_md(SSL *ssl) {
-  switch (SSL_CIPHER_get_id(SSL_get_current_cipher(ssl))) {
+static const EVP_MD *crypto_cipher_id_get_md(uint32_t cipher_id) {
+  switch (cipher_id) {
   case TLS1_CK_AES_128_GCM_SHA256:
   case TLS1_CK_CHACHA20_POLY1305_SHA256:
     return EVP_sha256();
@@ -154,15 +157,47 @@ static const EVP_MD *crypto_ssl_get_md(SSL *ssl) {
   }
 }
 
+static int supported_cipher_id(uint32_t cipher_id) {
+  switch (cipher_id) {
+  case TLS1_CK_AES_128_GCM_SHA256:
+  case TLS1_CK_AES_256_GCM_SHA384:
+  case TLS1_CK_CHACHA20_POLY1305_SHA256:
+    return 1;
+  default:
+    return 0;
+  }
+}
+
+static ngtcp2_crypto_ctx *crypto_ctx_cipher_id(ngtcp2_crypto_ctx *ctx,
+                                               uint32_t cipher_id) {
+  ngtcp2_crypto_aead_init(&ctx->aead,
+                          (void *)crypto_cipher_id_get_aead(cipher_id));
+  ctx->md.native_handle = (void *)crypto_cipher_id_get_md(cipher_id);
+  ctx->hp.native_handle = (void *)crypto_cipher_id_get_hp(cipher_id);
+  ctx->max_encryption = crypto_cipher_id_get_aead_max_encryption(cipher_id);
+  ctx->max_decryption_failure =
+    crypto_cipher_id_get_aead_max_decryption_failure(cipher_id);
+
+  return ctx;
+}
+
 ngtcp2_crypto_ctx *ngtcp2_crypto_ctx_tls(ngtcp2_crypto_ctx *ctx,
                                          void *tls_native_handle) {
   SSL *ssl = tls_native_handle;
-  ngtcp2_crypto_aead_init(&ctx->aead, (void *)crypto_ssl_get_aead(ssl));
-  ctx->md.native_handle = (void *)crypto_ssl_get_md(ssl);
-  ctx->hp.native_handle = (void *)crypto_ssl_get_hp(ssl);
-  ctx->max_encryption = crypto_ssl_get_aead_max_encryption(ssl);
-  ctx->max_decryption_failure = crypto_ssl_get_aead_max_decryption_failure(ssl);
-  return ctx;
+  const SSL_CIPHER *cipher = SSL_get_current_cipher(ssl);
+  uint32_t cipher_id;
+
+  if (cipher == NULL) {
+    return NULL;
+  }
+
+  cipher_id = SSL_CIPHER_get_id(cipher);
+
+  if (!supported_cipher_id(cipher_id)) {
+    return NULL;
+  }
+
+  return crypto_ctx_cipher_id(ctx, cipher_id);
 }
 
 ngtcp2_crypto_ctx *ngtcp2_crypto_ctx_tls_early(ngtcp2_crypto_ctx *ctx,
@@ -379,13 +414,13 @@ int ngtcp2_crypto_hp_mask(uint8_t *dest, const ngtcp2_crypto_cipher *hp,
     AES_ecb_encrypt(sample, dest, &ctx->aes_key, 1);
     return 0;
   case NGTCP2_CRYPTO_BORINGSSL_CIPHER_TYPE_CHACHA20:
-#if defined(WORDS_BIGENDIAN)
+#ifdef WORDS_BIGENDIAN
     counter = (uint32_t)sample[0] + (uint32_t)(sample[1] << 8) +
               (uint32_t)(sample[2] << 16) + (uint32_t)(sample[3] << 24);
-#else  /* !WORDS_BIGENDIAN */
+#else  /* !defined(WORDS_BIGENDIAN) */
     memcpy(&counter, sample, sizeof(counter));
-#endif /* !WORDS_BIGENDIAN */
-    CRYPTO_chacha_20(dest, PLAINTEXT, sizeof(PLAINTEXT) - 1, ctx->key,
+#endif /* !defined(WORDS_BIGENDIAN) */
+    CRYPTO_chacha_20(dest, PLAINTEXT, ngtcp2_strlen_lit(PLAINTEXT), ctx->key,
                      sample + sizeof(counter), counter);
     return 0;
   default:
@@ -394,16 +429,17 @@ int ngtcp2_crypto_hp_mask(uint8_t *dest, const ngtcp2_crypto_cipher *hp,
   }
 }
 
-int ngtcp2_crypto_read_write_crypto_data(ngtcp2_conn *conn,
-                                         ngtcp2_crypto_level crypto_level,
-                                         const uint8_t *data, size_t datalen) {
+int ngtcp2_crypto_read_write_crypto_data(
+  ngtcp2_conn *conn, ngtcp2_encryption_level encryption_level,
+  const uint8_t *data, size_t datalen) {
   SSL *ssl = ngtcp2_conn_get_tls_native_handle(conn);
   int rv;
   int err;
 
   if (SSL_provide_quic_data(
-          ssl, ngtcp2_crypto_boringssl_from_ngtcp2_crypto_level(crypto_level),
-          data, datalen) != 1) {
+        ssl,
+        ngtcp2_crypto_boringssl_from_ngtcp2_encryption_level(encryption_level),
+        data, datalen) != 1) {
     return -1;
   }
 
@@ -423,7 +459,7 @@ int ngtcp2_crypto_read_write_crypto_data(ngtcp2_conn *conn,
 
         SSL_reset_early_data_reject(ssl);
 
-        rv = ngtcp2_conn_early_data_rejected(conn);
+        rv = ngtcp2_conn_tls_early_data_rejected(conn);
         if (rv != 0) {
           return -1;
         }
@@ -438,7 +474,7 @@ int ngtcp2_crypto_read_write_crypto_data(ngtcp2_conn *conn,
       return 0;
     }
 
-    ngtcp2_conn_handshake_completed(conn);
+    ngtcp2_conn_tls_handshake_completed(conn);
   }
 
   rv = SSL_process_quic_post_handshake(ssl);
@@ -467,7 +503,7 @@ int ngtcp2_crypto_set_remote_transport_params(ngtcp2_conn *conn, void *tls) {
 
   SSL_get_peer_quic_transport_params(ssl, &tp, &tplen);
 
-  rv = ngtcp2_conn_decode_remote_transport_params(conn, tp, tplen);
+  rv = ngtcp2_conn_decode_and_set_remote_transport_params(conn, tp, tplen);
   if (rv != 0) {
     ngtcp2_conn_set_tls_error(conn, rv);
     return -1;
@@ -485,33 +521,34 @@ int ngtcp2_crypto_set_local_transport_params(void *tls, const uint8_t *buf,
   return 0;
 }
 
-ngtcp2_crypto_level ngtcp2_crypto_boringssl_from_ssl_encryption_level(
-    enum ssl_encryption_level_t ssl_level) {
+ngtcp2_encryption_level ngtcp2_crypto_boringssl_from_ssl_encryption_level(
+  enum ssl_encryption_level_t ssl_level) {
   switch (ssl_level) {
   case ssl_encryption_initial:
-    return NGTCP2_CRYPTO_LEVEL_INITIAL;
+    return NGTCP2_ENCRYPTION_LEVEL_INITIAL;
   case ssl_encryption_early_data:
-    return NGTCP2_CRYPTO_LEVEL_EARLY;
+    return NGTCP2_ENCRYPTION_LEVEL_0RTT;
   case ssl_encryption_handshake:
-    return NGTCP2_CRYPTO_LEVEL_HANDSHAKE;
+    return NGTCP2_ENCRYPTION_LEVEL_HANDSHAKE;
   case ssl_encryption_application:
-    return NGTCP2_CRYPTO_LEVEL_APPLICATION;
+    return NGTCP2_ENCRYPTION_LEVEL_1RTT;
   default:
     assert(0);
     abort();
   }
 }
 
-enum ssl_encryption_level_t ngtcp2_crypto_boringssl_from_ngtcp2_crypto_level(
-    ngtcp2_crypto_level crypto_level) {
-  switch (crypto_level) {
-  case NGTCP2_CRYPTO_LEVEL_INITIAL:
+enum ssl_encryption_level_t
+ngtcp2_crypto_boringssl_from_ngtcp2_encryption_level(
+  ngtcp2_encryption_level encryption_level) {
+  switch (encryption_level) {
+  case NGTCP2_ENCRYPTION_LEVEL_INITIAL:
     return ssl_encryption_initial;
-  case NGTCP2_CRYPTO_LEVEL_HANDSHAKE:
+  case NGTCP2_ENCRYPTION_LEVEL_HANDSHAKE:
     return ssl_encryption_handshake;
-  case NGTCP2_CRYPTO_LEVEL_APPLICATION:
+  case NGTCP2_ENCRYPTION_LEVEL_1RTT:
     return ssl_encryption_application;
-  case NGTCP2_CRYPTO_LEVEL_EARLY:
+  case NGTCP2_ENCRYPTION_LEVEL_0RTT:
     return ssl_encryption_early_data;
   default:
     assert(0);
@@ -544,8 +581,8 @@ static int set_read_secret(SSL *ssl, enum ssl_encryption_level_t bssl_level,
                            size_t secretlen) {
   ngtcp2_crypto_conn_ref *conn_ref = SSL_get_app_data(ssl);
   ngtcp2_conn *conn = conn_ref->get_conn(conn_ref);
-  ngtcp2_crypto_level level =
-      ngtcp2_crypto_boringssl_from_ssl_encryption_level(bssl_level);
+  ngtcp2_encryption_level level =
+    ngtcp2_crypto_boringssl_from_ssl_encryption_level(bssl_level);
   (void)cipher;
 
   if (ngtcp2_crypto_derive_and_install_rx_key(conn, NULL, NULL, NULL, level,
@@ -561,8 +598,8 @@ static int set_write_secret(SSL *ssl, enum ssl_encryption_level_t bssl_level,
                             size_t secretlen) {
   ngtcp2_crypto_conn_ref *conn_ref = SSL_get_app_data(ssl);
   ngtcp2_conn *conn = conn_ref->get_conn(conn_ref);
-  ngtcp2_crypto_level level =
-      ngtcp2_crypto_boringssl_from_ssl_encryption_level(bssl_level);
+  ngtcp2_encryption_level level =
+    ngtcp2_crypto_boringssl_from_ssl_encryption_level(bssl_level);
   (void)cipher;
 
   if (ngtcp2_crypto_derive_and_install_tx_key(conn, NULL, NULL, NULL, level,
@@ -577,8 +614,8 @@ static int add_handshake_data(SSL *ssl, enum ssl_encryption_level_t bssl_level,
                               const uint8_t *data, size_t datalen) {
   ngtcp2_crypto_conn_ref *conn_ref = SSL_get_app_data(ssl);
   ngtcp2_conn *conn = conn_ref->get_conn(conn_ref);
-  ngtcp2_crypto_level level =
-      ngtcp2_crypto_boringssl_from_ssl_encryption_level(bssl_level);
+  ngtcp2_encryption_level level =
+    ngtcp2_crypto_boringssl_from_ssl_encryption_level(bssl_level);
   int rv;
 
   rv = ngtcp2_conn_submit_crypto_data(conn, level, data, datalen);
@@ -607,8 +644,8 @@ static int send_alert(SSL *ssl, enum ssl_encryption_level_t bssl_level,
 }
 
 static SSL_QUIC_METHOD quic_method = {
-    set_read_secret, set_write_secret, add_handshake_data,
-    flush_flight,    send_alert,
+  set_read_secret, set_write_secret, add_handshake_data,
+  flush_flight,    send_alert,
 };
 
 static void crypto_boringssl_configure_context(SSL_CTX *ssl_ctx) {
