@@ -43,6 +43,7 @@
 #endif // defined(HAVE_ARPA_INET_H)
 
 #include <array>
+#include <variant>
 
 #include <ngtcp2/ngtcp2.h>
 
@@ -56,22 +57,34 @@ enum network_error {
   NETWORK_ERR_DROP_CONN = -14,
 };
 
-union in_addr_union {
-  in_addr in;
-  in6_addr in6;
-};
+using InAddr = std::variant<std::monostate, in_addr, in6_addr>;
 
-union sockaddr_union {
-  sockaddr_storage storage;
-  sockaddr sa;
-  sockaddr_in6 in6;
-  sockaddr_in in;
-};
+using Sockaddr = std::variant<std::monostate, sockaddr_in, sockaddr_in6>;
 
 struct Address {
-  socklen_t len;
-  union sockaddr_union su;
-  uint32_t ifindex;
+  // as_sockaddr returns the pointer to the stored address casted to
+  // const sockaddr *.
+  [[nodiscard]] const sockaddr *as_sockaddr() const;
+  [[nodiscard]] sockaddr *as_sockaddr();
+  // family returns the address family.
+  [[nodiscard]] int family() const;
+  // port returns the port.
+  [[nodiscard]] uint16_t port() const;
+  // port sets |port| to this address.
+  void port(uint16_t port);
+  // set stores |sa| to this address.  The address family is
+  // determined by |sa|->sa_family, and |sa| must point to the memory
+  // that contains valid object which is either sockaddr_in or
+  // sockaddr_in6.
+  void set(const sockaddr *sa);
+  // size returns the size of the stored address.
+  [[nodiscard]] socklen_t size() const;
+  // empty returns true if this address does not contain any
+  // meaningful address.
+  [[nodiscard]] bool empty() const;
+
+  Sockaddr skaddr;
+  uint32_t ifindex{};
 };
 
 } // namespace ngtcp2
