@@ -34,6 +34,7 @@
 #include <span>
 
 #include <ngtcp2/ngtcp2.h>
+#include <nghttp3/nghttp3.h>
 
 #include "network.h"
 
@@ -63,6 +64,11 @@ inline constexpr uint32_t TLS_ALERT_ECH_REQUIRED = 121;
 
 inline constexpr size_t MAX_RECV_PKTS = 64;
 
+union SharedVec {
+  ngtcp2_vec v2;
+  nghttp3_vec v3;
+};
+
 // msghdr_get_ecn gets ECN bits from |msg|.  |family| is the address
 // family from which packet is received.
 uint8_t msghdr_get_ecn(msghdr *msg, int family);
