@@ -35,7 +35,7 @@
 
 class TLSClientContext {
 public:
-  TLSClientContext();
+  TLSClientContext() = default;
   ~TLSClientContext();
 
   int init(const char *private_key_file, const char *cert_file);
@@ -45,7 +45,7 @@ public:
   void enable_keylog();
 
 private:
-  WOLFSSL_CTX *ssl_ctx_;
+  WOLFSSL_CTX *ssl_ctx_{};
 };
 
 #endif // !defined(TLS_CLIENT_CONTEXT_WOLFSSL_H)
