@@ -114,7 +114,7 @@ typedef enum {
 
 typedef struct ngtcp2_path_challenge_entry {
   ngtcp2_path_storage ps;
-  uint8_t data[8];
+  uint8_t data[NGTCP2_PATH_CHALLENGE_DATALEN];
 } ngtcp2_path_challenge_entry;
 
 void ngtcp2_path_challenge_entry_init(ngtcp2_path_challenge_entry *pcent,
@@ -387,14 +387,14 @@ struct ngtcp2_conn {
     ngtcp2_tstamp last_max_data_ts;
 
     struct {
-      /* state is the state of ECN validation */
-      ngtcp2_ecn_state state;
       /* validation_start_ts is the timestamp when ECN validation is
          started.  It is UINT64_MAX if it has not started yet. */
       ngtcp2_tstamp validation_start_ts;
       /* dgram_sent is the number of UDP datagram sent during ECN
          validation period. */
       size_t dgram_sent;
+      /* state is the state of ECN validation */
+      ngtcp2_ecn_state state;
     } ecn;
 
     struct {
@@ -545,13 +545,13 @@ struct ngtcp2_conn {
     /* retry_aead_ctx is AEAD cipher context to verify Retry packet
        integrity.  It is used by client only. */
     ngtcp2_crypto_aead_ctx retry_aead_ctx;
+    /* decryption_failure_count is the number of received packets that
+       fail authentication. */
+    uint64_t decryption_failure_count;
     /* tls_error is TLS related error. */
     int tls_error;
     /* tls_alert is TLS alert generated by the local endpoint. */
     uint8_t tls_alert;
-    /* decryption_failure_count is the number of received packets that
-       fail authentication. */
-    uint64_t decryption_failure_count;
   } crypto;
 
   /* pkt contains the packet intermediate construction data to support
@@ -561,13 +561,13 @@ struct ngtcp2_conn {
     ngtcp2_pkt_hd hd;
     ngtcp2_ppe ppe;
     ngtcp2_frame_chain **pfrc;
+    ngtcp2_ssize hs_spktlen;
     int pkt_empty;
     int hd_logged;
+    int require_padding;
     /* flags is bitwise OR of zero or more of
        NGTCP2_RTB_ENTRY_FLAG_*. */
     uint16_t rtb_entry_flags;
-    ngtcp2_ssize hs_spktlen;
-    int require_padding;
   } pkt;
 
   struct {
@@ -623,7 +623,6 @@ struct ngtcp2_conn {
   ngtcp2_log log;
   ngtcp2_qlog qlog;
   ngtcp2_rst rst;
-  ngtcp2_cc_algo cc_algo;
   union {
     ngtcp2_cc cc;
     ngtcp2_cc_reno reno;
@@ -650,6 +649,7 @@ struct ngtcp2_conn {
   uint32_t negotiated_version;
   /* flags is bitwise OR of zero or more of NGTCP2_CONN_FLAG_*. */
   uint32_t flags;
+  ngtcp2_cc_algo cc_algo;
   int server;
 };
 
@@ -661,9 +661,6 @@ typedef enum ngtcp2_vmsg_type {
 typedef struct ngtcp2_vmsg_stream {
   /* strm is a stream that data is sent to. */
   ngtcp2_strm *strm;
-  /* flags is bitwise OR of zero or more of
-     NGTCP2_WRITE_STREAM_FLAG_*. */
-  uint32_t flags;
   /* data is the pointer to ngtcp2_vec array which contains the stream
      data to send. */
   const ngtcp2_vec *data;
@@ -672,6 +669,9 @@ typedef struct ngtcp2_vmsg_stream {
   /* pdatalen is the pointer to the variable which the number of bytes
      written is assigned to if pdatalen is not NULL. */
   ngtcp2_ssize *pdatalen;
+  /* flags is bitwise OR of zero or more of
+     NGTCP2_WRITE_STREAM_FLAG_*. */
+  uint32_t flags;
 } ngtcp2_vmsg_stream;
 
 typedef struct ngtcp2_vmsg_datagram {
@@ -682,12 +682,12 @@ typedef struct ngtcp2_vmsg_datagram {
   size_t datacnt;
   /* dgram_id is an opaque identifier chosen by an application. */
   uint64_t dgram_id;
-  /* flags is bitwise OR of zero or more of
-     NGTCP2_WRITE_DATAGRAM_FLAG_*. */
-  uint32_t flags;
   /* paccepted is the pointer to the variable which, if it is not
      NULL, is assigned nonzero if data is written to a packet. */
   int *paccepted;
+  /* flags is bitwise OR of zero or more of
+     NGTCP2_WRITE_DATAGRAM_FLAG_*. */
+  uint32_t flags;
 } ngtcp2_vmsg_datagram;
 
 typedef struct ngtcp2_vmsg {
